==> haskell-hiedb-0.4.3.0-131.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-In3a35d9RZoBKNa9hffqgQ
key:                  hiedb-0.4.3.0-In3a35d9RZoBKNa9hffqgQ
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  aa236cfd9f1c052d136b2346160ee894
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-In3a35d9RZoBKNa9hffqgQ
depends:
    algebraic-graphs-0.7-J6zQywoEVrzAk0rClbBWfi
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    filepath-1.4.300.1 ghc-9.6.6
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    sqlite-simple-0.4.19.0-J9daIpu6jyNBDZIdTcHL6M
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hiedb-0.4.3.0-132-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-JrTc7LV9Ba920uOneyacpK
key:                  hiedb-0.4.3.0-JrTc7LV9Ba920uOneyacpK
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  71b5570490016cf57dcb0f7d1ce2aa62
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-JrTc7LV9Ba920uOneyacpK
depends:
    algebraic-graphs-0.7-D3hwQEt6m96749FCoGQ1wQ
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    filepath-1.4.300.1 ghc-9.6.6
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax mtl-2.3.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    sqlite-simple-0.4.19.0-5vfJm6muwz0GpIPQ7iB7ck
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
